@@ -31,7 +31,6 @@ from gitlab.exceptions import GitlabHttpError
 
 from assignbot.s3_utils import download_file, upload_file
 
-TO_REVIEW_LABEL = "To Review"
 REVIEW_ACCESS_LEVEL = 30  # developper
 DO_NOT_REVIEW_TAG = "no-assignbot"
 
@@ -50,7 +49,6 @@ Thank you for your time.
 
 def all_reviews(cnx, reviewer_id="None"):
     merge_requests = cnx.mergerequests.list(
-        labels=TO_REVIEW_LABEL,
         state="opened",
         wip="no",
         scope="all",
@@ -58,17 +56,6 @@ def all_reviews(cnx, reviewer_id="None"):
         all=True,
     )
 
-    merge_requests.extend(
-        cnx.mergerequests.list(
-            labels="None",
-            state="opened",
-            wip="no",
-            scope="all",
-            reviewer_id=reviewer_id,
-            all=True,
-        )
-    )
-
     shuffle(merge_requests)
 
     for merge_request in merge_requests:
